sqltriples.Intersection

Module sqltriples :: Class Intersection |
[show private | hide private]
[frames | no frames]

## Class Intersection

    Query --+
            |
     SetQuery --+
                |
               Intersection

A class representing the intersection of a number of queries.

Method Summary
| `__init__(self, store, queries)`
Inherited from SetQuery
| ``get_query`(self, index)`
Inherited from Query
| ``__getitem__`(self, i)`
| ``__len__`(self)`
| ``__repr__`(self)`
| ``get_child_query`(self, index)` Obtain the query clause and values (as a 2-tuple) which links this object's query to a parent query.

Generated by Epydoc 2.1 on Fri Mar 31 17:48:37 2006 | http://epydoc.sf.net